import type { Knex } from 'knex';
import { IDataReader, IFindingOptions } from './interfaces/data-reader.interface';
import { ICreationOptions, IDataWriter, IDeletionOptions, IUpdatingOptions } from './interfaces/data-writer.interface';
export declare abstract class BaseRepository<T> implements IDataReader<T>, IDataWriter<T> {
    readonly model: any;
    private knexInstance;
    constructor(model: any, knexInstance: Knex);
    createMany(items: Omit<Partial<T>, 'id'>[], options: ICreationOptions): Promise<T[]>;
    create(data: Omit<Partial<T>, 'id'>, options?: ICreationOptions): Promise<T>;
    delete(conditions: Partial<T>, options?: IDeletionOptions): Promise<number>;
    update(conditions: Partial<T>, data: Partial<T>, options?: IUpdatingOptions): Promise<number>;
    getOne(conditions: Partial<T>, options?: IFindingOptions): Promise<T | undefined>;
    getAll(conditions: Partial<T>, options?: IFindingOptions): Promise<T[]>;
    qb(): Knex.QueryBuilder;
    knex(): Knex;
    getKnexInstance(): Promise<any>;
}
